@@ -1,4 +1,4 @@
-/* $Id: gdict-app.c,v 1.57.2.2 2002/09/19 17:23:21 gman Exp $ */
+/* $Id: gdict-app.c,v 1.61 2003/05/31 05:54:47 dcransto Exp $ */
 /* -*- mode: c; style: k&r; c-basic-offset: 4 -*- */
 
 /*
@@ -64,19 +64,12 @@ dict_context_t *context;
 
 static void gdict_edit_menu_set_sensitivity (gboolean flag);
 
-static gint
-socket_dialog_close_cb (GtkWidget *widget, gpointer data) 
-{
-    socket_error_dialog = NULL;
-    return FALSE;
-}
-
 static void
 socket_error_cb (GtkWidget *widget, gchar *message, gpointer data) 
 {
     socket_error_dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
                                   		  GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-                                  		  "%s", message, NULL); 
+                                  		  "%s", message); 
     gtk_dialog_run (GTK_DIALOG (socket_error_dialog));
     gtk_widget_destroy (socket_error_dialog);
     
@@ -101,6 +94,10 @@ gdict_init_context (void)
     
     defbox->context = context;
 
+#ifdef ENABLE_IPV6
+    if (context->host6info)
+	return 0;
+#endif
     if (context->hostinfo)
 	return 0;
     else
@@ -523,14 +520,6 @@ find_again_cb (GtkMenuItem *menuitem, gpointer user_data)
 	find_cb (NULL, NULL);
 }
 
-static void
-pref_dialog_apply_cb (GtkWidget *widget, gpointer user_data) 
-{
-    gdict_defbox_reset (defbox, context);
-    if (speller) 
-	gdict_speller_reset (speller, context);
-}
-
 void
 gdict_not_online () 
 {
@@ -542,7 +531,7 @@ gdict_not_online ()
     		           "or you are not connected to the Internet."));
     w = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
                                      GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
-                                     "%s", s, NULL); 
+                                     "%s", s); 
     gtk_dialog_run (GTK_DIALOG (w));
     gtk_widget_destroy (w);
     g_free (s);
@@ -768,9 +757,8 @@ GtkWidget *gdict_app_create (gboolean applet) {
     GtkWidget *vbox;
     GtkWidget *hbox;
     GtkWidget *button;
-    GtkWidget *label, *word_label;
+    GtkWidget *word_label;
     GtkWidget *scrolled;
-    GtkWidget *defbox_vscrollbar;
     GtkTooltips *tooltips;
     static GtkTargetEntry drop_targets [] = {
     	{ "UTF8_STRING", 0, 0 },
@@ -800,12 +788,12 @@ GtkWidget *gdict_app_create (gboolean applet) {
     gtk_widget_show (vbox);
     gnome_app_set_contents (GNOME_APP (gdict_app), vbox);
     
-    hbox = gtk_hbox_new (FALSE, 6);
+    hbox = gtk_hbox_new (FALSE, 12);
     gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
     gtk_widget_show (hbox);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
     
-    word_label = gtk_label_new_with_mnemonic (_("_Word: "));
+    word_label = gtk_label_new_with_mnemonic (_("_Word:"));
     gtk_widget_show ( GTK_WIDGET(word_label) );
     gtk_box_pack_start (GTK_BOX (hbox), word_label, FALSE, FALSE, 0);
     
@@ -845,7 +833,7 @@ GtkWidget *gdict_app_create (gboolean applet) {
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
                                         GTK_POLICY_AUTOMATIC,             
 	       				GTK_POLICY_AUTOMATIC);
-    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled), GTK_SHADOW_ETCHED_IN);
+    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled), GTK_SHADOW_NONE);
 
     gtk_widget_show (scrolled);
   
