@@ -1,4 +1,4 @@
-/* $Id: gdict-pref-dialog.c,v 1.36 2003/05/31 06:03:27 dcransto Exp $ */
+/* $Id: gdict-pref-dialog.c,v 1.38.2.1 2003/10/19 06:40:28 kmaraas Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -170,7 +170,7 @@ create_dialog (GDictPrefDialog *pref_dialog)
     gtk_window_set_policy (GTK_WINDOW (pref_dialog), FALSE, FALSE, FALSE);    
     gtk_container_set_border_width (GTK_CONTAINER (pref_dialog), 5);
     vbox = GTK_DIALOG (pref_dialog)->vbox;
-
+    gtk_box_set_spacing (GTK_BOX (vbox), 2);
     
     pref_dialog->table = GTK_TABLE (gtk_table_new (5, 3, FALSE));
     gtk_box_pack_start (GTK_BOX (GTK_DIALOG (pref_dialog)->vbox), GTK_WIDGET (pref_dialog->table), TRUE, TRUE, 0);
@@ -184,6 +184,8 @@ create_dialog (GDictPrefDialog *pref_dialog)
     		      G_CALLBACK (smart_lookup_cb), pref_dialog);
     gtk_table_attach_defaults (pref_dialog->table, GTK_WIDGET (pref_dialog->smart_lookup_btn),
     			       1, 3, 2, 3);
+    if ( ! gconf_client_key_is_writable (gdict_get_gconf_client (), "/apps/gnome-dictionary/smart", NULL))
+	    gtk_widget_set_sensitive (GTK_WIDGET (pref_dialog->smart_lookup_btn), FALSE);
     
     pref_dialog->server_entry = GTK_ENTRY (gtk_entry_new ());			       
     gtk_table_attach (pref_dialog->table, 
@@ -213,6 +215,12 @@ create_dialog (GDictPrefDialog *pref_dialog)
     if( gail_loaded )
         add_atk_namedesc(GTK_WIDGET(button), NULL, _("Reset server to default"));
 
+    if ( ! gconf_client_key_is_writable (gdict_get_gconf_client (), "/apps/gnome-dictionary/server", NULL)) {
+	    gtk_widget_set_sensitive (GTK_WIDGET (pref_dialog->server_entry), FALSE);
+	    gtk_widget_set_sensitive (server_label, FALSE);
+	    gtk_widget_set_sensitive (button, FALSE);
+    }
+
     port_label = gtk_label_new_with_mnemonic (_("_Port:"));
     gtk_table_attach_defaults (pref_dialog->table, port_label, 0, 1, 1, 2);
     gtk_label_set_justify (GTK_LABEL (port_label), GTK_JUSTIFY_LEFT);
@@ -250,6 +258,12 @@ create_dialog (GDictPrefDialog *pref_dialog)
 
     }
 
+    if ( ! gconf_client_key_is_writable (gdict_get_gconf_client (), "/apps/gnome-dictionary/port", NULL)) {
+	    gtk_widget_set_sensitive (GTK_WIDGET (pref_dialog->port_entry), FALSE);
+	    gtk_widget_set_sensitive (port_label, FALSE);
+	    gtk_widget_set_sensitive (button, FALSE);
+    }
+
     db_label = gtk_label_new_with_mnemonic (_("_Database:"));
     gtk_label_set_justify (GTK_LABEL (db_label), GTK_JUSTIFY_LEFT);
     gtk_misc_set_alignment (GTK_MISC (db_label), 0, 0.5);
@@ -581,6 +595,7 @@ pref_status_cb (dict_command_t *command, DictStatusCode code,
     GtkOptionMenu *option_menu = NULL;
     GtkMenu *use_menu = NULL;
     gint row = 0;
+    gboolean writable;
     
     g_return_if_fail (data != NULL);
     g_return_if_fail (IS_GDICT_PREF_DIALOG (data));
@@ -599,9 +614,7 @@ pref_status_cb (dict_command_t *command, DictStatusCode code,
         
         option_menu = GTK_OPTION_MENU (gtk_option_menu_new ());
         gtk_option_menu_set_menu (option_menu, GTK_WIDGET (use_menu));
-        alignment = gtk_alignment_new (0, 0.5, 0, 0);
-        /*gtk_container_add (GTK_CONTAINER (alignment),
-			   GTK_WIDGET (option_menu));*/
+
         gtk_table_attach_defaults (pref_dialog->table, GTK_WIDGET (option_menu), 
                                    1, 3, row, row + 1);
         gtk_widget_show_all (GTK_WIDGET (pref_dialog->table));
@@ -617,6 +630,11 @@ pref_status_cb (dict_command_t *command, DictStatusCode code,
                 add_atk_relation( GTK_WIDGET (option_menu), db_label, ATK_RELATION_LABELLED_BY);
 
             }
+
+            writable = gconf_client_key_is_writable (gdict_get_gconf_client (), "/apps/gnome-dictionary/database", NULL);
+
+	    gtk_widget_set_sensitive (db_label, writable);
+	    gtk_widget_set_sensitive (GTK_WIDGET (option_menu), writable);
         }
         else if (command->cmd == C_SHOW_STRAT)
         {
@@ -629,6 +647,11 @@ pref_status_cb (dict_command_t *command, DictStatusCode code,
                 add_atk_relation( GTK_WIDGET (option_menu), strat_label, ATK_RELATION_LABELLED_BY);
 
             }
+
+            writable = gconf_client_key_is_writable (gdict_get_gconf_client (), "/apps/gnome-dictionary/strategy", NULL);
+
+	    gtk_widget_set_sensitive (strat_label, writable);
+	    gtk_widget_set_sensitive (GTK_WIDGET (option_menu), writable);
         }
     }
 }
