@@ -250,8 +250,6 @@ static void
 badblocks_check_cleanup (GFloppy *floppy,
 			 gchar   *bb_filename)
 {
-	GList *l;
-
 	g_return_if_fail (floppy->formatting_mode == GFLOPPY_FORMAT_THOROUGH);
 	g_return_if_fail (floppy->badblocks_list != NULL);
 
@@ -297,7 +295,7 @@ execute_fs_creation_cmd (GFloppy           *floppy,
 			   &status, &error)) {
 		gchar *msg;
 
-		msg = g_strdup_printf (_("Error while spawning the (%s) command: %s."), args->pdata[0], error->message);
+		msg = g_strdup_printf (_("Error while spawning the (%s) command: %s."), (char *)args->pdata[0], error->message);
 		fd_print (floppy, MSG_ERROR, msg);
 		g_free (msg);
 
@@ -336,7 +334,7 @@ execute_fs_creation_cmd (GFloppy           *floppy,
 		if ((type != CMD_MKE2FS || has_real_err_output) &&
 		     strlen (err_output) > 0) {
 			msg = g_strdup_printf (_("The filesystem creation utility (%s) reported the following errors:\n\n%s (%d)"),
-					       args->pdata[0], err_output, strlen (err_output)); // FIXME:
+					       (char *)args->pdata[0], err_output, strlen (err_output)); // FIXME:
 			fd_print (floppy, MSG_ERROR, msg);
 			g_free (msg);
 
@@ -440,7 +438,6 @@ execute_mbadblocks (GFloppy *floppy)
 static int
 format_ext2fs (GFloppy *floppy)
 {
-	gchar *cmd;
 	gint rc = 0;
 	gchar *bb_filename = NULL;
 
@@ -481,7 +478,6 @@ format_ext2fs (GFloppy *floppy)
 static int
 format_fat (GFloppy *floppy)
 {
-	gchar *cmd;
 	gint rc = 0;
 	gchar *bb_filename = NULL;
 
